/* RSIMonCalc.cpp
 * For use with RSIMon
 * written by Maritn Thompson
 * mjthompson@iee.org
 *
 */
/* RSIMon - A pain based usage monitor
 * Copyright (C) 2000 Martin Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#include <stdafx.h>
#include "RSIMonCalc.h"

CRSIMonCalc::CRSIMonCalc(void)
{

}

void CRSIMonCalc::Init(void)
{
	m_fPain = 0.0f;
}

BOOL CRSIMonCalc::Update(float dist, float dragdist, int clicks, int doubleclicks, int keys, INT time)
{
	static int break_time = 0;
	int action; 
	if (time == 0)
		return FALSE;
	m_iTotalDistance += (int)(((dragdist+dist)*10.0)+0.5);
	m_iTotalKeys += keys;
//	TRACE("%d\n", time);
	
	action = 0;
	if (dist > 0)
	{
		float t;
		t=m_fMaxDistance/(1000.0f*dist/(float)time);
		m_fPain += m_fDistWeight * t;
		action++;
	}
	if (dragdist > 0)
	{
		float t;
		t=m_fMaxDistance/(1000.0f*dragdist/(float)time);
		m_fPain += m_fDragDistWeight * t;
		action++;
	}
	if (clicks > 0)
	{
		m_fPain += m_fClicksWeight * (float)clicks;
		action++;
	}
	if (doubleclicks > 0)
	{
		m_fPain += m_fDoubleClicksWeight * (float)doubleclicks;
		action++;
	}
	if (keys > 0)
	{
		m_fPain += m_fKeyboardWeight * (float)keys;
		action++;
	}

	if (action == 0)
	{
		break_time += time;
		if (break_time > m_iBreakLimit)
		{
			m_fPain -= m_fDecay*(float)time;
			if (m_fPain < 0.0) 
				m_fPain = 0.0;
		}
	}
	else
	{
		break_time = 0;
	}

	if (m_fPain<m_fThresh)
		return FALSE;
	else
		return TRUE;
}



