/* RSIMon.h
 * For use with RSIMon
 * written by Maritn Thompson
 * mjthompson@iee.org
 *
 */
/* RSIMon - A pain based usage monitor
 * Copyright (C) 2000 Martin Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef RSIMONCALC_H
#define RSIMONCALC_H

class CRSIMonCalc
{
public:
	CRSIMonCalc(void);
	void Init(void);

	void SetTotalDistance(int d) { m_iTotalDistance = d;};
	void SetTotalKeys(int d) { m_iTotalKeys = d;};
	void SetMaxDistance(int d) { m_fMaxDistance = (float)d;};
	void SetThreshold(int d) { m_fThresh = (float)d;};
	void SetDecay(int d) { m_fDecay = (float)d/10.0f;};
	void SetClickPain(int d) { m_fClicksWeight = (float)d;};
	void SetDoubleclickPain(int d) { m_fDoubleClicksWeight = (float)d;};
	void SetMovePain(int d) { m_fDistWeight = (float)d;};
	void SetDragPain(int d) { m_fDragDistWeight = (float)d;};
	void SetKeyboardPain(int d) { m_fKeyboardWeight = (float)d;};
	void SetBreakLimit(int d) {m_iBreakLimit = d;};

	int GetPain(void) {return (int)m_fPain;};
	int GetTotalDistance(void) {return m_iTotalDistance;};
	int GetTotalKeys(void) {return m_iTotalKeys;};
	int GetThreshold(void) {return (int)m_fThresh;};
	int GetDecay(void) { return(int)(m_fDecay*10.0);};
	int GetClickPain(void) { return(int)m_fClicksWeight;};
	int GetDoubleclickPain(void) { return(int)m_fDoubleClicksWeight;};
	int GetMovePain(void) { return(int)m_fDistWeight;};
	int GetDragPain(void) { return(int)m_fDragDistWeight;};
	int GetKeyboardPain(void) { return(int)m_fKeyboardWeight;};
	int GetBreakLimit(void) {return m_iBreakLimit;};

	BOOL Update(float dist, float dragdist, int clicks, int doubleclicks, int keys, INT time);
	//CRSIMonCalc~
protected:
	int m_iTotalDistance;
	int m_iTotalKeys;
	int m_iBreakLimit;
	float m_fThresh;
	float m_fMaxDistance;
	float m_fPain;
	float m_fDecay;
	float m_fDistWeight;
	float m_fDragDistWeight;
	float m_fClicksWeight;
	float m_fDoubleClicksWeight;
	float m_fKeyboardWeight;
};



#endif