/* RSIMonDlg.cpp
 * For use with RSIMon
 * written by Maritn Thompson
 * mjthompson@iee.org
 *
 */
/* RSIMon - A pain based usage monitor
 * Copyright (C) 2000 Martin Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

#include "stdafx.h"
#include <math.h>
#include "RSImon.h"
#include "RSIMonCalc.h"
#include "RSImonDlg.h"
#include "..\rsimonhooks\RSIMonHooks.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

// Update every TICKTIME ms
#define TICKTIME	(50)

static void ShowMessage(void);

/////////////////////////////////////////////////////////////////////////////
// CAboutDlg dialog used for App About

class CAboutDlg : public CDialog
{
public:
	CAboutDlg();

// Dialog Data
	//{{AFX_DATA(CAboutDlg)
	enum { IDD = IDD_ABOUTBOX };
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CAboutDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:
	//{{AFX_MSG(CAboutDlg)
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialog(CAboutDlg::IDD)
{
	//{{AFX_DATA_INIT(CAboutDlg)
	//}}AFX_DATA_INIT
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CAboutDlg)
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
	//{{AFX_MSG_MAP(CAboutDlg)
		// No message handlers
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CRSImonDlg dialog
CRSImonDlg::CRSImonDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CRSImonDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CRSImonDlg)
	m_RadioNormalValue = -1;
	m_RadioPainfulValue = -1;
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

CRSImonDlg::~CRSImonDlg()
{
	Shell_NotifyIcon(NIM_DELETE, &m_nidTrayData);
}

void CRSImonDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CRSImonDlg)
	DDX_Control(pDX, IDC_BUTTON_SAVE, m_ButtonSave);
	DDX_Control(pDX, IDC_RADIO_NORMAL, m_RadioNormal);
	DDX_Control(pDX, IDC_RADIO_PAINFUL, m_RadioPainful);
	DDX_Radio(pDX, IDC_RADIO_NORMAL, m_RadioNormalValue);
	DDX_Radio(pDX, IDC_RADIO_PAINFUL, m_RadioPainfulValue);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CRSImonDlg, CDialog)
	//{{AFX_MSG_MAP(CRSImonDlg)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	ON_WM_TIMER()
	ON_BN_CLICKED(IDC_DEBUGGING, OnDebugging)
	ON_BN_CLICKED(IDC_RESET, OnReset)
	ON_BN_CLICKED(IDC_BUTTON_SAVE, OnButtonSave)
	ON_EN_KILLFOCUS(IDC_EDIT_THRESHOLD, OnKillfocusEditThreshold)
	ON_EN_KILLFOCUS(IDC_EDIT_DECAY, OnKillfocusEditDecay)
	ON_BN_CLICKED(IDC_TOTRAY, OnTotray)
	ON_WM_MOUSEMOVE()
	ON_WM_CANCELMODE()
	ON_BN_CLICKED(ID_CLOSE, OnClose)
	ON_EN_KILLFOCUS(IDC_EDIT_CLICKPAIN, OnKillfocusEditClickPain)
	ON_EN_KILLFOCUS(IDC_EDIT_DOUBLECLICKPAIN, OnKillfocusEditDoubleclickPain)
	ON_EN_KILLFOCUS(IDC_EDIT_DRAGPAIN, OnKillfocusEditDragPain)
	ON_EN_KILLFOCUS(IDC_EDIT_KEYBOARDPAIN, OnKillfocusEditKeyboardPain)
	ON_EN_KILLFOCUS(IDC_EDIT_MOVEPAIN, OnKillfocusEditMovePain)
	ON_BN_CLICKED(IDC_RADIO_PAINFUL, OnRadioPainful)
	ON_BN_CLICKED(IDC_RADIO_NORMAL, OnRadioNormal)
	ON_WM_LBUTTONDOWN()
	ON_EN_KILLFOCUS(IDC_EDIT_BREAKLIMIT, OnKillfocusEditBreakLimit)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CRSImonDlg message handlers

BOOL CRSImonDlg::OnInitDialog()
{
	BOOL ret;
	CDialog::OnInitDialog();

	// Add "About..." menu item to system menu.

	// IDM_ABOUTBOX must be in the system command range.
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != NULL)
	{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
		{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	m_pApp = AfxGetApp();
	m_bNeedSave = FALSE;
	m_bHadWarning =  FALSE;
	
	m_hHandIcon = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_HAND00), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	ASSERT(m_hHandIcon);
	m_hHandIcon20 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_HAND20), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	ASSERT(m_hHandIcon20);
	m_hHandIcon40 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_HAND40), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	ASSERT(m_hHandIcon40);
	m_hHandIcon60 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_HAND60), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	ASSERT(m_hHandIcon60);
	m_hHandIcon80 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_HAND80), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	ASSERT(m_hHandIcon80);
	m_hHandIcon100 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_HAND100), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	ASSERT(m_hHandIcon100);
	m_hThrobIcon1 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_THROB1), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);
	m_hThrobIcon2 = (HICON)LoadImage(AfxGetInstanceHandle(), MAKEINTRESOURCE(IDI_THROB2), IMAGE_ICON, 16, 16, LR_DEFAULTCOLOR);

	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

	// Set up the system wide mouse and keyboard hooks..
	m_hDll = LoadLibrary("RSIMonHooks.dll");
	ASSERT(m_hDll);
	ret = InitHooks();
	ASSERT(ret);

	// Read stuff from registry
	int iDist = m_pApp->GetProfileInt("Main", "Distance", 0);
	int iKeys = m_pApp->GetProfileInt("Main", "TotalKeys", 0);

	// initialise calculations
	RSIMonCalc.Init();
	RSIMonCalc.SetTotalDistance(iDist);
	RSIMonCalc.SetTotalKeys(iKeys);
	RSIMonCalc.SetMaxDistance(GetSystemMetrics(SM_CXSCREEN));

	CString str = m_pApp->GetProfileString("Main", "Set", "Good");
	if (str == "Good")
		OnRadioNormal();
	else
		OnRadioPainful();

	// setup Tray icon
	m_nidTrayData.hWnd = m_hWnd;
	m_nidTrayData.uID = 1;
	m_nidTrayData.uFlags = NIF_ICON|NIF_TIP|NIF_MESSAGE;
	m_nidTrayData.uCallbackMessage = WM_MOUSEMOVE;
	m_nidTrayData.hIcon = m_hHandIcon;
	strcpy(m_nidTrayData.szTip, "RSIMon");

	// Start things going
	ret=SetTimer(10, TICKTIME, NULL);
	if (!ret)
		AfxMessageBox("Can't start Timer");
	
	ret=Shell_NotifyIcon(NIM_ADD, &m_nidTrayData);
	ASSERT(ret);

	m_bWasInTray = FALSE;
	m_bInTray = FALSE;

	return TRUE;  // return TRUE  unless you set the focus to a control
}

void CRSImonDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();
	}
	else
	{
		CDialog::OnSysCommand(nID, lParam);
	}
}

void CRSImonDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, (WPARAM) dc.GetSafeHdc(), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CRSImonDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

void CRSImonDlg::OnTimer(UINT nIDEvent) 
{
	static int on = 0;
	static BOOL shown = FALSE;
	static BOOL WasMinimized = FALSE;
	static int numCalls = 0;
	CString str;
	SYSTEMTIME ThisTime, TimeDiff;
	static SYSTEMTIME LastTime;
	BOOL ret;
	static int clicks = 0;
	static int doubleclicks = 0;

	if (numCalls == 0)
		GetSystemTime(&LastTime);

	//xxx this should be a member
	CWnd* w = GetDlgItem(IDC_ALERT);

	numCalls++;
	if (numCalls == 1000)
		numCalls = 1;
	ret = GetData(&m_mdData);

	GetSystemTime(&ThisTime);

	// How long since we last ran?
	TimeDiff = ThisTime;

	TimeDiff.wMilliseconds -= LastTime.wMilliseconds;
	if (TimeDiff.wMilliseconds > 999) {TimeDiff.wMilliseconds += 1000U; TimeDiff.wSecond -= 1U;}
	TimeDiff.wSecond -= LastTime.wSecond;
	if (TimeDiff.wSecond > 59) {TimeDiff.wSecond += 60; TimeDiff.wMinute -= 1;}
	TimeDiff.wMinute -= LastTime.wMinute;
	if (TimeDiff.wMinute > 59) {TimeDiff.wMinute += 60; TimeDiff.wHour -= 1;}
	TimeDiff.wHour -= LastTime.wHour;
	if (TimeDiff.wHour > 24) {TimeDiff.wHour += 24; TimeDiff.wDay -= 1;}
	// Can't figure out a better way than to ignore month ends yet
	TimeDiff.wDay -= LastTime.wDay;
	if (TimeDiff.wDay > 31) {LastTime = ThisTime;return;}
	LastTime = ThisTime;

	DWORD time_ms = TimeDiff.wMilliseconds+1000*TimeDiff.wSecond;	// Ignore >= minutes

	// Do pain calculation
	clicks += m_mdData.clicks;
	doubleclicks += m_mdData.doubleclicks;
	ret = RSIMonCalc.Update(m_mdData.dist, m_mdData.dragdist, 
		m_mdData.clicks, m_mdData.doubleclicks, m_mdData.keys, time_ms);
	if (ret) // create warning!
	{
		m_bHadWarning = TRUE;
		ret=SetWindowPos(&wndTopMost, 0,0,0,0, SWP_SHOWWINDOW|SWP_NOSIZE|SWP_NOMOVE);
		ASSERT(ret);
		ret=SetWindowPos(&wndNoTopMost, 0,0,0,0, SWP_SHOWWINDOW|SWP_NOSIZE|SWP_NOMOVE);
		ASSERT(ret);
		m_bInTray = FALSE;
		// xxx do this properly
		if (numCalls %10 == 0)
		{
			FlashWindow(TRUE);
			if (on)
			{
				SetTrayIcon(m_hThrobIcon1);
				on = 0;
			}
			else
			{
				SetTrayIcon(m_hThrobIcon2);
				on = 1;
			}
		}
	}
	else
	{
		FlashWindow(FALSE);
		if (on == 0)
		{
			on = 1;
		}
		if (!m_bInTray && m_bWasInTray && RSIMonCalc.GetPain() == 0)
		{
			if (m_bHadWarning)
			{
				m_bHadWarning =  FALSE;
				ret = SetWindowPos(&wndBottom, 0,0,0,0, SWP_HIDEWINDOW|SWP_NOSIZE|SWP_NOMOVE);
			}
		}
		static float last_fraction = 0.0f;
		float fraction;
		fraction = RSIMonCalc.GetPain()/(float)RSIMonCalc.GetThreshold();
		fraction *= 5.0f;
		fraction += 0.5f;
		fraction = (float)((int)fraction)/5.0f;
		if (fraction != last_fraction)
		{
			HICON thisicon;
			last_fraction = fraction;
			thisicon = m_hHandIcon;
			if (fraction >= 1.0)
				thisicon = m_hHandIcon100;
			if (fraction < 1.0)
				thisicon = m_hHandIcon80;
			if (fraction < 0.8)
				thisicon = m_hHandIcon60;
			if (fraction < 0.6)
				thisicon = m_hHandIcon40;
			if (fraction < 0.4)
				thisicon = m_hHandIcon20;
			if (fraction < 0.2)
			thisicon = m_hHandIcon;
			SetTrayIcon(thisicon);
		}
		
	}
	str.Format("%6u", numCalls);
	SetDlgItemText(IDC_NUMCALLS, str);

	str.Format("%6.0f", m_mdData.dist);
	SetDlgItemText(IDC_DISTANCE, str);
	str.Format("%6.0f", m_mdData.dragdist);
	SetDlgItemText(IDC_DRAGDISTANCE, str);

	str.Format("%2d %2d", clicks, doubleclicks);
	SetDlgItemText(IDC_CLICKS, str);

	str.Format("%6d", RSIMonCalc.GetPain());
	SetDlgItemText(IDC_PAIN, str);

	str.Format("%12ld", RSIMonCalc.GetTotalDistance());
	SetDlgItemText(IDC_TOTAL, str);
	str.Format("%12ld", RSIMonCalc.GetTotalKeys());
	SetDlgItemText(IDC_TOTALKEYS, str);

	// xxx do this 100 poroperly
	if (numCalls % 100 == 0)
	{
		ret=m_pApp->WriteProfileInt("Main", "Distance", RSIMonCalc.GetTotalDistance());
		if (!ret)
			AfxMessageBox ("Can't write to INI file?");
		ret=m_pApp->WriteProfileInt("Main", "TotalKeys", RSIMonCalc.GetTotalKeys());
		if (!ret)
			AfxMessageBox ("Can't write to INI file?");
	}
//	LastPoint = point;
	CDialog::OnTimer(nIDEvent);
}

void CRSImonDlg::SetTrayIcon(HICON hIcon)
{
	BOOL ret;

	m_nidTrayData.hIcon = hIcon;
	ret=Shell_NotifyIcon(NIM_MODIFY, &m_nidTrayData);
	ASSERT(ret);
}


void CRSImonDlg::OnReset() 
{
	RSIMonCalc.Init();
}

void CRSImonDlg::OnButtonSave() 
{
	BOOL ret;
	CString str;

	str = m_pApp->GetProfileString("Main", "Set", "Good");

	ret=m_pApp->WriteProfileInt(str, "Distance", RSIMonCalc.GetTotalDistance());
	ASSERT(ret);	
	ret=m_pApp->WriteProfileInt(str, "Threshold", RSIMonCalc.GetThreshold());
	ASSERT(ret);	
	ret=m_pApp->WriteProfileInt(str, "Decay", RSIMonCalc.GetDecay());
	ASSERT(ret);	
	m_pApp->WriteProfileInt(str, "KeyboardPain", RSIMonCalc.GetKeyboardPain());
	ASSERT(ret);	
	m_pApp->WriteProfileInt(str, "ClickPain", RSIMonCalc.GetClickPain());
	ASSERT(ret);	
	m_pApp->WriteProfileInt(str, "DoubleclickPain", RSIMonCalc.GetDoubleclickPain());
	ASSERT(ret);	
	m_pApp->WriteProfileInt(str, "MovePain", RSIMonCalc.GetMovePain());
	ASSERT(ret);	
	m_pApp->WriteProfileInt(str, "DragPain", RSIMonCalc.GetDragPain());
	ASSERT(ret);	
	m_pApp->WriteProfileInt(str, "BreakLimit", RSIMonCalc.GetBreakLimit());
	ASSERT(ret);	

	DisableSaveButton();
}

void CRSImonDlg::DisableSaveButton(void)
{
	m_ButtonSave.ModifyStyle(0, WS_DISABLED, SWP_NOACTIVATE);
	m_bNeedSave = 0;
	m_ButtonSave.Invalidate();
	m_ButtonSave.PostMessage(WM_PAINT);
}

void CRSImonDlg::EnableSaveButton(void)
{
	m_ButtonSave.ModifyStyle(WS_DISABLED,0 ,SWP_NOACTIVATE);
	m_bNeedSave = 1;
	m_ButtonSave.Invalidate();
	m_ButtonSave.PostMessage(WM_PAINT);
}

#define FOCUS_MACRO(name, upcase_name)	\
void CRSImonDlg::OnKillfocusEdit##name##() \
{\
	int i;\
	int Success;\
	i=GetDlgItemInt(IDC_EDIT_##upcase_name, &Success, FALSE);\
	if (Success)\
	{\
		if (RSIMonCalc.Get##name##() != i)\
			EnableSaveButton();\
		RSIMonCalc.Set##name(i);\
	}\
	else\
	{\
		SetDlgItemInt(IDC_EDIT_##upcase_name, RSIMonCalc.Get##name##());\
	}\
}

FOCUS_MACRO(Threshold, THRESHOLD)
FOCUS_MACRO(Decay, DECAY)
FOCUS_MACRO(ClickPain, CLICKPAIN)
FOCUS_MACRO(DoubleclickPain, DOUBLECLICKPAIN)
FOCUS_MACRO(KeyboardPain, KEYBOARDPAIN)
FOCUS_MACRO(DragPain, DRAGPAIN)
FOCUS_MACRO(MovePain, MOVEPAIN)
FOCUS_MACRO(BreakLimit, BREAKLIMIT)

void CRSImonDlg::OnTotray() 
{
	int ret;
	Shell_NotifyIcon(NIM_MODIFY, &m_nidTrayData);
	ret = SetWindowPos(&wndBottom, 0,0,0,0, SWP_HIDEWINDOW|SWP_NOSIZE|SWP_NOMOVE);
	ASSERT(ret);
	m_bWasInTray = TRUE;
	m_bInTray = TRUE;
}

void CRSImonDlg::OnMouseMove(UINT nFlags, CPoint point) 
{
	int ret;
	CString str;
	str.Format("RSIMon : %d", int(RSIMonCalc.GetPain()));
	strcpy(m_nidTrayData.szTip, LPCTSTR(str));
	Shell_NotifyIcon(NIM_MODIFY, &m_nidTrayData);
    if ( point.x == WM_LBUTTONDBLCLK )
    {
		ret=SetWindowPos(&wndTopMost, 0,0,0,0, SWP_SHOWWINDOW|SWP_NOSIZE|SWP_NOMOVE);
		ret=SetWindowPos(&wndNoTopMost, 0,0,0,0, SWP_SHOWWINDOW|SWP_NOSIZE|SWP_NOMOVE);
		ASSERT(ret);
		//SetActiveWindow();
		m_bWasInTray = FALSE;
		m_bInTray = FALSE;
    }
/*    else if ( point.x == WM_RBUTTONUP )
    {
        CMenu * pSysMenu = GetSystemMenu( FALSE );
        if ( pSysMenu )
        {
            CPoint mouse;
            GetCursorPos(&mouse);
            pSysMenu->TrackPopupMenu( TPM_CENTERALIGN, mouse.x, mouse.y, this );
        }
    }*/
	else
	{

		CDialog::OnMouseMove(nFlags, point);
	}
}

void CRSImonDlg::OnCancelMode() 
{
	CDialog::OnCancelMode();
}

void CRSImonDlg::OnCancel() 
{
	OnTotray();	
}

void CRSImonDlg::OnClose() 
{
	AskSave();
	BOOL ret;
	ret=KillTimer(10);
	ASSERT(ret);
	Shell_NotifyIcon(NIM_DELETE, &m_nidTrayData);
	ret = KillHooks();
	ASSERT(ret);
	ret = FreeLibrary(m_hDll);
	ASSERT(ret);
	CDialog::OnOK();	
}

void CRSImonDlg::GetRegistryParameters(CString str)
{
	int iThresh = m_pApp->GetProfileInt(str, "Threshold", 100);
	int iDecay= m_pApp->GetProfileInt(str, "Decay", 100);
	int iKeyboardPain = m_pApp->GetProfileInt(str, "KeyboardPain", 10);
	int iClickPain = m_pApp->GetProfileInt(str, "ClickPain", 10);
	int iDoubleclickPain = m_pApp->GetProfileInt(str, "DoubleclickPain", 10);
	int iMovePain = m_pApp->GetProfileInt(str, "MovePain", 10);
	int iDragPain = m_pApp->GetProfileInt(str, "DragPain", 10);
	int iBreakLimit= m_pApp->GetProfileInt(str, "BreakLimit", 100);

	RSIMonCalc.SetThreshold(iThresh);
	RSIMonCalc.SetDecay(iDecay);
	RSIMonCalc.SetKeyboardPain(iKeyboardPain);
	RSIMonCalc.SetClickPain(iClickPain);
	RSIMonCalc.SetDoubleclickPain(iDoubleclickPain);
	RSIMonCalc.SetMovePain(iMovePain);
	RSIMonCalc.SetDragPain(iDragPain);
	RSIMonCalc.SetBreakLimit(iBreakLimit);

	// initialise dialog items
	SetDlgItemInt(IDC_EDIT_THRESHOLD, RSIMonCalc.GetThreshold());
	SetDlgItemInt(IDC_EDIT_DECAY, RSIMonCalc.GetDecay());
	SetDlgItemInt(IDC_EDIT_KEYBOARDPAIN, RSIMonCalc.GetKeyboardPain());
	SetDlgItemInt(IDC_EDIT_CLICKPAIN, RSIMonCalc.GetClickPain());
	SetDlgItemInt(IDC_EDIT_DOUBLECLICKPAIN, RSIMonCalc.GetDoubleclickPain());
	SetDlgItemInt(IDC_EDIT_MOVEPAIN, RSIMonCalc.GetMovePain());
	SetDlgItemInt(IDC_EDIT_DRAGPAIN, RSIMonCalc.GetDragPain());
	SetDlgItemInt(IDC_EDIT_BREAKLIMIT, RSIMonCalc.GetBreakLimit());
}

void ShowMessage(void)
{
	LPVOID lpMsgBuf;

FormatMessage( 
    FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
    NULL,
    GetLastError(),
    MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
    (LPTSTR) &lpMsgBuf,
    0,
    NULL 
);

// Display the string.
MessageBox( NULL, (LPCSTR)lpMsgBuf, "GetLastError", MB_OK|MB_ICONINFORMATION );

// Free the buffer.
LocalFree( lpMsgBuf );
 
}

int CRSImonDlg::AskSave()
{
	if (m_bNeedSave)
	{
		int ret = AfxMessageBox("Settings have changed since last save.  Save Data?", MB_YESNOCANCEL);
		if (ret == IDCANCEL)
			return 0;
		else if (ret == IDYES)
			OnButtonSave();
		else if (ret == IDNO)
			;
		else
			AfxMessageBox("Invalid return from dialog");
	}
	return 1;
}

void CRSImonDlg::OnRadioPainful() 
{
	m_RadioNormal.SetCheck(0);
	m_RadioPainful.SetCheck(1);
	if (AskSave() != 0)
	{
		m_pApp->WriteProfileString("Main", "Set", "Painful");
		GetRegistryParameters(m_pApp->GetProfileString("Main", "Set"));
		DisableSaveButton();
	}
	else
	{
		m_RadioNormal.SetCheck(1);
		m_RadioPainful.SetCheck(0);
	}
}

void CRSImonDlg::OnRadioNormal() 
{
	m_RadioPainful.SetCheck(0);
	m_RadioNormal.SetCheck(1);
	if (AskSave() != 0)
	{
		m_pApp->WriteProfileString("Main", "Set", "Good");
		GetRegistryParameters(m_pApp->GetProfileString("Main", "Set"));
		DisableSaveButton();
	}
	else
	{
		m_RadioNormal.SetCheck(0);
		m_RadioPainful.SetCheck(1);
	}
}

void CRSImonDlg::OnDebugging() 
{
	CString str;
	GetDlgItemText(IDC_DEBUGGING, str) ;
	if (str == "Show Debugging &Info")
	{
		SetDlgItemText(IDC_DEBUGGING, "Hide Debugging &Info");
		DebugDisplay(0);
	}
	else
	{
		SetDlgItemText(IDC_DEBUGGING, "Show Debugging &Info");
		DebugDisplay(1);
	}
}

void CRSImonDlg::DebugDisplay(int Show)
{
}

