/* RSIMonHooks.cpp
 * For use with RSIMon
 * written by Maritn Thompson
 * mjthompson@iee.org
 *
 */
/* RSIMon - A pain based usage monitor
 * Copyright (C) 2000 Martin Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
// Provides hooks of keyboard and mouse for RSIMon
#include <windows.h>
#include <math.h>
#include "RSIMonHooks.h"

#pragma data_seg(".shared")     // Make a new section that we'll make shared
HHOOK hMouseHook = 0;
HHOOK hKBHook = 0;
MouseData data = {0.0f, 0.0f, 0, 0, 0};
BOOL initialised = FALSE;
BOOL bButtonDown = FALSE;
HINSTANCE hMyHandle = 0;
int refcount = 0;
#pragma data_seg()

LRESULT CALLBACK KBHook(int nCode, WPARAM wParam, LPARAM lParam)
{
	if (nCode < 0)
		return(CallNextHookEx(hKBHook, nCode, wParam, lParam));
	if (lParam & 0x40000000UL)
		data.keys++;

	return(CallNextHookEx(hKBHook, nCode, wParam, lParam));
}

LRESULT CALLBACK MouseHook(int nCode, WPARAM wParam, LPARAM lParam)
{
	MOUSEHOOKSTRUCT *pM;
	static POINT LastPoint = {0,0};
	POINT point;

	if (nCode < 0)
		return(CallNextHookEx(hMouseHook, nCode, wParam, lParam));
	pM = (MOUSEHOOKSTRUCT *)lParam;
	switch (wParam)
	{
		case WM_LBUTTONDOWN:
		case WM_MBUTTONDOWN:
		case WM_RBUTTONDOWN:
			bButtonDown = TRUE;
			break;
		case WM_LBUTTONUP:
		case WM_MBUTTONUP:
		case WM_RBUTTONUP:
			data.clicks++;
			bButtonDown = FALSE;
			break;
		case WM_LBUTTONDBLCLK:
		case WM_MBUTTONDBLCLK:
		case WM_RBUTTONDBLCLK:
			bButtonDown = FALSE;
			data.doubleclicks++;
			data.clicks-=2;
			break;
		case WM_MOUSEMOVE:
			point = pM->pt;
			if (bButtonDown)
				data.dragdist += (sqrtf((float)(LastPoint.x-point.x)*(LastPoint.x-point.x) + (LastPoint.y-point.y)*(LastPoint.y-point.y)));
			else
				data.dist += (sqrtf((float)(LastPoint.x-point.x)*(LastPoint.x-point.x) + (LastPoint.y-point.y)*(LastPoint.y-point.y)));
			LastPoint = point;
			break;
	}
	return(CallNextHookEx(hMouseHook, nCode, wParam, lParam));
}

__declspec(dllexport) __stdcall GetData(MouseData *ret)
{
	*ret = data;
	data.dist = 0;
	data.dragdist = 0;
	data.clicks = 0;
	data.doubleclicks = 0;
	data.keys = 0;
	return (1);
}

__declspec(dllexport) __stdcall InitHooks(void)
{
	if (initialised)
		return (0);

	initialised = 1;
	data.dist = 0;
	data.dragdist = 0;
	data.clicks = 0;
	data.doubleclicks = 0;
	data.keys = 0;

	bButtonDown = FALSE;
 
		refcount++;
		if (refcount == 1)		// Deliberate call by 'owner'
		{
			// set up memory mapped file...

			hMouseHook = SetWindowsHookEx( WH_MOUSE, (HOOKPROC)MouseHook, (HINSTANCE)hMyHandle, 0);
			if (hMouseHook == 0)
			{
				return (0);
			}
			hKBHook = SetWindowsHookEx( WH_KEYBOARD, (HOOKPROC)KBHook, (HINSTANCE)hMyHandle, 0);
			if (hKBHook == 0)
			{
				return (0);
			}
		}
	return (1);
}

__declspec(dllexport) __stdcall KillHooks(void)
{
	if (!initialised)
		return(0);
	initialised = 0;

		refcount--;
		if (refcount == 0)
		{
			if (hMouseHook)
				UnhookWindowsHookEx(hMouseHook);
			if (hKBHook)
				UnhookWindowsHookEx(hKBHook);
		}
		return TRUE;
	return (1);
}

BOOL APIENTRY DllMain(HINSTANCE hModule, 
                      DWORD  ul_reason_for_call, 
                      LPVOID lpReserved)
{
	// Should allocate Thread Local Storage here...
	hMyHandle = hModule;
    switch( ul_reason_for_call ) {
    case DLL_PROCESS_ATTACH:
       //DisableThreadLibraryCalls( hModule );
		return TRUE;
    case DLL_THREAD_ATTACH:
		return TRUE;
    case DLL_THREAD_DETACH:
		return TRUE;
    case DLL_PROCESS_DETACH:
		return TRUE;
    }
    return TRUE;
}

//-------------------------------------------------------------
// Dummy startup routine that does nothing except call DllMain
// This cuts out all of the standard startup code crud that
// bloats the DLL, and makes it take longer to load
// MJT does it make any odds?
//-------------------------------------------------------------
//BOOL WINAPI _DllMainCRTStartup(
//    HINSTANCE hinstDLL,     // handle to DLL module
//    DWORD fdwReason,        // reason for calling function
//    LPVOID lpvReserved)     // reserved
//{
//    return DllMain( hinstDLL, fdwReason, lpvReserved );
//}